@@ -3,7 +3,7 @@ package Params::ValidationCompiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Params::ValidationCompiler::Compiler;
 
@@ -40,7 +40,7 @@ Params::ValidationCompiler - Build an optimized subroutine parameter validator o
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ version 0.14
             },
         );
 
-        sub do_something {
+        sub foo {
             my %args = $validator->(@_);
         }
     }
@@ -78,7 +78,7 @@ version 0.14
             ],
         );
 
-        sub do_something {
+        sub bar {
             my ( $int, $str ) = $validator->(@_);
         }
     }
@@ -95,7 +95,7 @@ version 0.14
             named_to_list => 1,
         );
 
-        sub do_something {
+        sub baz {
             my ( $foo, $bar ) = $validator->(@_);
         }
     }
